DevX
DevX is a library for common functions and utilities used in microservice development.
Installation
To install DevX, run the following command:
go get github.com/xBlaz3kx/DevX@latest
Usage
package main
import (
"github.com/xBlaz3kx/DevX"
)
func main() {
// Your code here
}
Contributing
We appreciate your help! Please see CONTRIBUTING for details on how to contribute to this library.
License
This project is licensed under the MIT License. See the LICENSE file for details.